#!/bin/bash
set -euo pipefail

# Parse arguments to wrapper.
OUTDIR="$1"
FNAME="$2"
EXEC="$3"

# Parse MPI Rank.
if [[ -n ${OMPI_COMM_WORLD_RANK+z} ]]; then
    # MPICH
    export MPI_RANK=${OMPI_COMM_WORLD_RANK}
elif [[ -n ${MV2_COMM_WORLD_RANK+z} ]]; then
    # OpenMPI
    export MPI_RANK=${MV2_COMM_WORLD_RANK}
elif [[ -n ${SLURM_PROCID+z} ]]; then
    # SLURM
    export MPI_RANK=${SLURM_PROCID}
else
    echo "Unknown MPI layer detected! Must use OpenMPI, MVAPICH, or SLURM"
    exit 1
fi

# Setup arguments for storing profiling output.
PID="$$"
OUTDIR="${OUTDIR}/rank_${PID}_${MPI_RANK}"
OUTFILE="${FNAME}_${PID}_${MPI_RANK}.csv"

# Get HIP traces and hardware counters thereafter.
rocprof --hip-trace --stats -d ${OUTDIR} -o "${OUTDIR}/${OUTFILE}" "$EXEC"
# TODO: Wait required for all SRUN processes?
# rocprof -i "$PROFILING/rocprof_counters.txt" -d ${OUTDIR} -o "${OUTDIR}/${OUTFILE}" "$EXEC"
